@@ -63,10 +63,21 @@ if TYPE_CHECKING:
 
 logger = AdapterLogger("Snowflake")
 
-if os.getenv("DBT_SNOWFLAKE_CONNECTOR_DEBUG_LOGGING"):
+
+def setup_snowflake_logging(level: str):
     for logger_name in ["snowflake.connector", "botocore", "boto3"]:
-        logger.debug(f"Setting {logger_name} to DEBUG")
-        logger.set_adapter_dependency_log_level(logger_name, "DEBUG")
+        logger.debug(f"Setting {logger_name} to {level} (file logging only)")
+        logger.set_adapter_dependency_log_level(logger_name, level)
+
+
+if snowflake_level := os.getenv("DBT_SNOWFLAKE_CONNECTOR_DEBUG_LOGGING"):
+    if snowflake_level.upper() in ["INFO", "DEBUG", "ERROR"]:
+        setup_snowflake_logging(snowflake_level.upper())
+    else:
+        setup_snowflake_logging("DEBUG")
+else:
+    setup_snowflake_logging("ERROR")
+
 
 _TOKEN_REQUEST_URL = "https://{}.snowflakecomputing.com/oauth/token-request"
 
@@ -114,6 +125,9 @@ class SnowflakeCredentials(Credentials):
     # this needs to default to `None` so that we can tell if the user set it; see `__post_init__()`
     reuse_connections: Optional[bool] = None
     s3_stage_vpce_dns_name: Optional[str] = None
+    # Setting this to 0.0 will disable platform detection which adds query latency
+    # this should only be set to a non-zero value if you are using WIF authentication
+    platform_detection_timeout_seconds: float = 0.0
 
     def __post_init__(self):
         if self.authenticator != "oauth" and (self.oauth_client_secret or self.oauth_client_id):
@@ -182,6 +196,7 @@ class SnowflakeCredentials(Credentials):
             "insecure_mode",
             "reuse_connections",
             "s3_stage_vpce_dns_name",
+            "platform_detection_timeout_seconds",
         )
 
     def auth_args(self):
@@ -393,6 +408,7 @@ class SnowflakeConnectionManager(SQLConnectionManager):
                     client_session_keep_alive=creds.client_session_keep_alive,
                     application="dbt",
                     insecure_mode=creds.insecure_mode,
+                    platform_detection_timeout_seconds=creds.platform_detection_timeout_seconds,
                     session_parameters=session_parameters,
                     **creds.auth_args(),
                 )
